pub struct ExtUnitData {
pub name: UnitName,
pub sig: Signature,
}Expand description
Another unit referenced within a Function, Process, or Entity.
The linker will hook up external units to the actual counterparts as appropriate.
Fields
name: UnitNameThe name of the referenced unit.
sig: SignatureThe signature of the referenced unit.